@@ -12,7 +12,7 @@
  *
  * Also finds out IP of specified MAC
  *
- * $Id: arping.c,v 1.27 2000/09/18 19:12:17 marvin Exp $
+ * $Id: arping.c,v 1.28 2000/09/28 20:45:18 marvin Exp $
  */
 /*
  *  Copyright (C) 2000 Marvin (marvin@nss.nu)
@@ -34,14 +34,6 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#if USE_NETIF
-#include <net/if.h>
-#include <net/if_arp.h>
-#endif
-
-#include <libnet.h>
-#include <pcap.h>
-
 #ifndef ETH_ALEN
 #define ETH_ALEN 6
 #endif
@@ -50,6 +42,19 @@
 #define ETH_P_IP 0x0800
 #endif
 
+#if FREEBSD
+#include <sys/socket.h>
+#include "freebsd.h" 
+#endif
+
+#if USE_NETIF
+#include <net/if.h>
+#include <net/if_arp.h>
+#endif
+
+#include <libnet.h>
+#include <pcap.h>
+
 #if OPENBSD
 #include "openbsd.h"
 #endif
@@ -65,7 +70,7 @@
 #define DEBUG(a)
 #endif
 
-const float version = 0.92;
+const float version = 0.93;
 
 struct ether_addr *mymac;
 u_char eth_xmas[ETH_ALEN] = {0xff, 0xff, 0xff, 0xff, 0xff, 0xff};
